# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/trino/v1/catalog.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/trino/v1/catalog.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#yandex/cloud/trino/v1/catalog.proto\x12\x15yandex.cloud.trino.v1\x1a\x1dyandex/cloud/validation.proto\"\xb8\x04\n\tConnector\x12\x34\n\x04hive\x18\x01 \x01(\x0b\x32$.yandex.cloud.trino.v1.HiveConnectorH\x00\x12:\n\x07iceberg\x18\x02 \x01(\x0b\x32\'.yandex.cloud.trino.v1.IcebergConnectorH\x00\x12?\n\ndelta_lake\x18\x03 \x01(\x0b\x32).yandex.cloud.trino.v1.DeltaLakeConnectorH\x00\x12@\n\npostgresql\x18\x04 \x01(\x0b\x32*.yandex.cloud.trino.v1.PostgresqlConnectorH\x00\x12@\n\nclickhouse\x18\x05 \x01(\x0b\x32*.yandex.cloud.trino.v1.ClickhouseConnectorH\x00\x12\x34\n\x04tpch\x18\x06 \x01(\x0b\x32$.yandex.cloud.trino.v1.TPCHConnectorH\x00\x12\x36\n\x05tpcds\x18\x07 \x01(\x0b\x32%.yandex.cloud.trino.v1.TPCDSConnectorH\x00\x12\x38\n\x06oracle\x18\x08 \x01(\x0b\x32&.yandex.cloud.trino.v1.OracleConnectorH\x00\x12>\n\tsqlserver\x18\t \x01(\x0b\x32).yandex.cloud.trino.v1.SQLServerConnectorH\x00\x42\x0c\n\x04type\x12\x04\xc0\xc1\x31\x01\"\xd8\x01\n\x07\x43\x61talog\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x33\n\tconnector\x18\x03 \x01(\x0b\x32 .yandex.cloud.trino.v1.Connector\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12:\n\x06labels\x18\x05 \x03(\x0b\x32*.yandex.cloud.trino.v1.Catalog.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc2\x02\n\x0b\x43\x61talogSpec\x12,\n\x04name\x18\x01 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x39\n\tconnector\x18\x02 \x01(\x0b\x32 .yandex.cloud.trino.v1.ConnectorB\x04\xe8\xc7\x31\x01\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12{\n\x06labels\x18\x04 \x03(\x0b\x32..yandex.cloud.trino.v1.CatalogSpec.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc5\x02\n\x11\x43\x61talogUpdateSpec\x12(\n\x04name\x18\x01 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x33\n\tconnector\x18\x02 \x01(\x0b\x32 .yandex.cloud.trino.v1.Connector\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x81\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x34.yandex.cloud.trino.v1.CatalogUpdateSpec.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8d\x01\n\tMetastore\x12>\n\x04hive\x18\x01 \x01(\x0b\x32..yandex.cloud.trino.v1.Metastore.HiveMetastoreH\x00\x1a\x32\n\rHiveMetastore\x12\r\n\x03uri\x18\x01 \x01(\tH\x00\x42\x12\n\nconnection\x12\x04\xc0\xc1\x31\x01\x42\x0c\n\x04type\x12\x04\xc0\xc1\x31\x01\"\xc2\x02\n\nFileSystem\x12<\n\x02s3\x18\x01 \x01(\x0b\x32..yandex.cloud.trino.v1.FileSystem.S3FileSystemH\x00\x12M\n\x0b\x65xternal_s3\x18\x02 \x01(\x0b\x32\x36.yandex.cloud.trino.v1.FileSystem.ExternalS3FileSystemH\x00\x1a\x0e\n\x0cS3FileSystem\x1a\x88\x01\n\x14\x45xternalS3FileSystem\x12\x1c\n\x0e\x61ws_access_key\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1c\n\x0e\x61ws_secret_key\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1a\n\x0c\x61ws_endpoint\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x18\n\naws_region\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01\x42\x0c\n\x04type\x12\x04\xc0\xc1\x31\x01\"\xef\x02\n\rHiveConnector\x12\x39\n\tmetastore\x18\x01 \x01(\x0b\x32 .yandex.cloud.trino.v1.MetastoreB\x04\xe8\xc7\x31\x01\x12;\n\nfilesystem\x18\x02 \x01(\x0b\x32!.yandex.cloud.trino.v1.FileSystemB\x04\xe8\xc7\x31\x01\x12\xa8\x01\n\x15\x61\x64\x64itional_properties\x18\x03 \x03(\x0b\x32>.yandex.cloud.trino.v1.HiveConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf5\x02\n\x10IcebergConnector\x12\x39\n\tmetastore\x18\x01 \x01(\x0b\x32 .yandex.cloud.trino.v1.MetastoreB\x04\xe8\xc7\x31\x01\x12;\n\nfilesystem\x18\x02 \x01(\x0b\x32!.yandex.cloud.trino.v1.FileSystemB\x04\xe8\xc7\x31\x01\x12\xab\x01\n\x15\x61\x64\x64itional_properties\x18\x03 \x03(\x0b\x32\x41.yandex.cloud.trino.v1.IcebergConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf9\x02\n\x12\x44\x65ltaLakeConnector\x12\x39\n\tmetastore\x18\x01 \x01(\x0b\x32 .yandex.cloud.trino.v1.MetastoreB\x04\xe8\xc7\x31\x01\x12;\n\nfilesystem\x18\x02 \x01(\x0b\x32!.yandex.cloud.trino.v1.FileSystemB\x04\xe8\xc7\x31\x01\x12\xad\x01\n\x15\x61\x64\x64itional_properties\x18\x03 \x03(\x0b\x32\x43.yandex.cloud.trino.v1.DeltaLakeConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdb\x05\n\x14PostgresqlConnection\x12K\n\non_premise\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.trino.v1.PostgresqlConnection.OnPremiseH\x00\x12[\n\x12\x63onnection_manager\x18\x02 \x01(\x0b\x32=.yandex.cloud.trino.v1.PostgresqlConnection.ConnectionManagerH\x00\x1a\xa5\x01\n\tOnPremise\x12\x44\n\x0e\x63onnection_url\x18\x01 \x01(\tB,\xe8\xc7\x31\x01\xf2\xc7\x31$^jdbc:[a-z0-9]+://(?:.+:\\d+)/(?:.*)$\x12\x31\n\tuser_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1f\n\x08password\x18\x03 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x30-128\x1a\xe2\x02\n\x11\x43onnectionManager\x12#\n\rconnection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04\x31-50\x12\x30\n\x08\x64\x61tabase\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\xb8\x01\n\x15\x63onnection_properties\x18\x03 \x03(\x0b\x32W.yandex.cloud.trino.v1.PostgresqlConnection.ConnectionManager.ConnectionPropertiesEntryB@\xf2\xc7\x31\x14[-_0-9a-zA-Z.,:\\/_]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x12\x12\t[a-zA-Z]*\x1a\x05\x31-128\x1a;\n\x19\x43onnectionPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\x04type\x12\x04\xc0\xc1\x31\x01\"\xc4\x02\n\x13PostgresqlConnector\x12?\n\nconnection\x18\x01 \x01(\x0b\x32+.yandex.cloud.trino.v1.PostgresqlConnection\x12\xae\x01\n\x15\x61\x64\x64itional_properties\x18\x02 \x03(\x0b\x32\x44.yandex.cloud.trino.v1.PostgresqlConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdc\x05\n\x14\x43lickhouseConnection\x12K\n\non_premise\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.trino.v1.ClickhouseConnection.OnPremiseH\x00\x12[\n\x12\x63onnection_manager\x18\x02 \x01(\x0b\x32=.yandex.cloud.trino.v1.ClickhouseConnection.ConnectionManagerH\x00\x1a\xa5\x01\n\tOnPremise\x12\x44\n\x0e\x63onnection_url\x18\x01 \x01(\tB,\xe8\xc7\x31\x01\xf2\xc7\x31$^jdbc:[a-z0-9]+://(?:.+:\\d+)/(?:.*)$\x12\x31\n\tuser_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1f\n\x08password\x18\x03 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x30-128\x1a\xe3\x02\n\x11\x43onnectionManager\x12#\n\rconnection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04\x31-50\x12\x30\n\x08\x64\x61tabase\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\xb9\x01\n\x15\x63onnection_properties\x18\x03 \x03(\x0b\x32W.yandex.cloud.trino.v1.ClickhouseConnection.ConnectionManager.ConnectionPropertiesEntryBA\xf2\xc7\x31\x14[-_0-9a-zA-Z.,:\\/_]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x13\x12\n[a-zA-Z_]*\x1a\x05\x31-128\x1a;\n\x19\x43onnectionPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\x04type\x12\x04\xc0\xc1\x31\x01\"\xc4\x02\n\x13\x43lickhouseConnector\x12?\n\nconnection\x18\x01 \x01(\x0b\x32+.yandex.cloud.trino.v1.ClickhouseConnection\x12\xae\x01\n\x15\x61\x64\x64itional_properties\x18\x02 \x03(\x0b\x32\x44.yandex.cloud.trino.v1.ClickhouseConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf7\x01\n\rTPCHConnector\x12\xa8\x01\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32>.yandex.cloud.trino.v1.TPCHConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf9\x01\n\x0eTPCDSConnector\x12\xa9\x01\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32?.yandex.cloud.trino.v1.TPCDSConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x85\x02\n\x10OracleConnection\x12G\n\non_premise\x18\x01 \x01(\x0b\x32\x31.yandex.cloud.trino.v1.OracleConnection.OnPremiseH\x00\x1a\x99\x01\n\tOnPremise\x12\x38\n\x0e\x63onnection_url\x18\x01 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x18^jdbc:[a-z0-9]+:(?s:.*)$\x12\x31\n\tuser_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1f\n\x08password\x18\x03 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x30-128B\x0c\n\x04type\x12\x04\xc0\xc1\x31\x01\"\xb8\x02\n\x0fOracleConnector\x12;\n\nconnection\x18\x01 \x01(\x0b\x32\'.yandex.cloud.trino.v1.OracleConnection\x12\xaa\x01\n\x15\x61\x64\x64itional_properties\x18\x02 \x03(\x0b\x32@.yandex.cloud.trino.v1.OracleConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8b\x02\n\x13SQLServerConnection\x12J\n\non_premise\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.trino.v1.SQLServerConnection.OnPremiseH\x00\x1a\x99\x01\n\tOnPremise\x12\x38\n\x0e\x63onnection_url\x18\x01 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x18^jdbc:[a-z0-9]+:(?s:.*)$\x12\x31\n\tuser_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1f\n\x08password\x18\x03 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x30-128B\x0c\n\x04type\x12\x04\xc0\xc1\x31\x01\"\xc1\x02\n\x12SQLServerConnector\x12>\n\nconnection\x18\x01 \x01(\x0b\x32*.yandex.cloud.trino.v1.SQLServerConnection\x12\xad\x01\n\x15\x61\x64\x64itional_properties\x18\x02 \x03(\x0b\x32\x43.yandex.cloud.trino.v1.SQLServerConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\\\n\x19yandex.cloud.api.trino.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/trino/v1;trinob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.trino.v1.catalog_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.trino.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/trino/v1;trino'
  _globals['_CONNECTOR'].oneofs_by_name['type']._loaded_options = None
  _globals['_CONNECTOR'].oneofs_by_name['type']._serialized_options = b'\300\3011\001'
  _globals['_CATALOG_LABELSENTRY']._loaded_options = None
  _globals['_CATALOG_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CATALOGSPEC_LABELSENTRY']._loaded_options = None
  _globals['_CATALOGSPEC_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CATALOGSPEC'].fields_by_name['name']._loaded_options = None
  _globals['_CATALOGSPEC'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_CATALOGSPEC'].fields_by_name['connector']._loaded_options = None
  _globals['_CATALOGSPEC'].fields_by_name['connector']._serialized_options = b'\350\3071\001'
  _globals['_CATALOGSPEC'].fields_by_name['description']._loaded_options = None
  _globals['_CATALOGSPEC'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CATALOGSPEC'].fields_by_name['labels']._loaded_options = None
  _globals['_CATALOGSPEC'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_CATALOGUPDATESPEC_LABELSENTRY']._loaded_options = None
  _globals['_CATALOGUPDATESPEC_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CATALOGUPDATESPEC'].fields_by_name['name']._loaded_options = None
  _globals['_CATALOGUPDATESPEC'].fields_by_name['name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_CATALOGUPDATESPEC'].fields_by_name['description']._loaded_options = None
  _globals['_CATALOGUPDATESPEC'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CATALOGUPDATESPEC'].fields_by_name['labels']._loaded_options = None
  _globals['_CATALOGUPDATESPEC'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_METASTORE_HIVEMETASTORE'].oneofs_by_name['connection']._loaded_options = None
  _globals['_METASTORE_HIVEMETASTORE'].oneofs_by_name['connection']._serialized_options = b'\300\3011\001'
  _globals['_METASTORE'].oneofs_by_name['type']._loaded_options = None
  _globals['_METASTORE'].oneofs_by_name['type']._serialized_options = b'\300\3011\001'
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM'].fields_by_name['aws_access_key']._loaded_options = None
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM'].fields_by_name['aws_access_key']._serialized_options = b'\350\3071\001'
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM'].fields_by_name['aws_secret_key']._loaded_options = None
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM'].fields_by_name['aws_secret_key']._serialized_options = b'\350\3071\001'
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM'].fields_by_name['aws_endpoint']._loaded_options = None
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM'].fields_by_name['aws_endpoint']._serialized_options = b'\350\3071\001'
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM'].fields_by_name['aws_region']._loaded_options = None
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM'].fields_by_name['aws_region']._serialized_options = b'\350\3071\001'
  _globals['_FILESYSTEM'].oneofs_by_name['type']._loaded_options = None
  _globals['_FILESYSTEM'].oneofs_by_name['type']._serialized_options = b'\300\3011\001'
  _globals['_HIVECONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_HIVECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_HIVECONNECTOR'].fields_by_name['metastore']._loaded_options = None
  _globals['_HIVECONNECTOR'].fields_by_name['metastore']._serialized_options = b'\350\3071\001'
  _globals['_HIVECONNECTOR'].fields_by_name['filesystem']._loaded_options = None
  _globals['_HIVECONNECTOR'].fields_by_name['filesystem']._serialized_options = b'\350\3071\001'
  _globals['_HIVECONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_HIVECONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_ICEBERGCONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_ICEBERGCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_ICEBERGCONNECTOR'].fields_by_name['metastore']._loaded_options = None
  _globals['_ICEBERGCONNECTOR'].fields_by_name['metastore']._serialized_options = b'\350\3071\001'
  _globals['_ICEBERGCONNECTOR'].fields_by_name['filesystem']._loaded_options = None
  _globals['_ICEBERGCONNECTOR'].fields_by_name['filesystem']._serialized_options = b'\350\3071\001'
  _globals['_ICEBERGCONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_ICEBERGCONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_DELTALAKECONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_DELTALAKECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_DELTALAKECONNECTOR'].fields_by_name['metastore']._loaded_options = None
  _globals['_DELTALAKECONNECTOR'].fields_by_name['metastore']._serialized_options = b'\350\3071\001'
  _globals['_DELTALAKECONNECTOR'].fields_by_name['filesystem']._loaded_options = None
  _globals['_DELTALAKECONNECTOR'].fields_by_name['filesystem']._serialized_options = b'\350\3071\001'
  _globals['_DELTALAKECONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_DELTALAKECONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_POSTGRESQLCONNECTION_ONPREMISE'].fields_by_name['connection_url']._loaded_options = None
  _globals['_POSTGRESQLCONNECTION_ONPREMISE'].fields_by_name['connection_url']._serialized_options = b'\350\3071\001\362\3071$^jdbc:[a-z0-9]+://(?:.+:\\d+)/(?:.*)$'
  _globals['_POSTGRESQLCONNECTION_ONPREMISE'].fields_by_name['user_name']._loaded_options = None
  _globals['_POSTGRESQLCONNECTION_ONPREMISE'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_POSTGRESQLCONNECTION_ONPREMISE'].fields_by_name['password']._loaded_options = None
  _globals['_POSTGRESQLCONNECTION_ONPREMISE'].fields_by_name['password']._serialized_options = b'\350\3071\001\212\3101\0050-128'
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._loaded_options = None
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_id']._loaded_options = None
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_id']._serialized_options = b'\350\3071\001\212\3101\0041-50'
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER'].fields_by_name['database']._loaded_options = None
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER'].fields_by_name['database']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_properties']._loaded_options = None
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_properties']._serialized_options = b'\362\3071\024[-_0-9a-zA-Z.,:\\/_]*\202\3101\005<=256\212\3101\005<=128\262\3101\022\022\t[a-zA-Z]*\032\0051-128'
  _globals['_POSTGRESQLCONNECTION'].oneofs_by_name['type']._loaded_options = None
  _globals['_POSTGRESQLCONNECTION'].oneofs_by_name['type']._serialized_options = b'\300\3011\001'
  _globals['_POSTGRESQLCONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_POSTGRESQLCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_POSTGRESQLCONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_POSTGRESQLCONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_CLICKHOUSECONNECTION_ONPREMISE'].fields_by_name['connection_url']._loaded_options = None
  _globals['_CLICKHOUSECONNECTION_ONPREMISE'].fields_by_name['connection_url']._serialized_options = b'\350\3071\001\362\3071$^jdbc:[a-z0-9]+://(?:.+:\\d+)/(?:.*)$'
  _globals['_CLICKHOUSECONNECTION_ONPREMISE'].fields_by_name['user_name']._loaded_options = None
  _globals['_CLICKHOUSECONNECTION_ONPREMISE'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_CLICKHOUSECONNECTION_ONPREMISE'].fields_by_name['password']._loaded_options = None
  _globals['_CLICKHOUSECONNECTION_ONPREMISE'].fields_by_name['password']._serialized_options = b'\350\3071\001\212\3101\0050-128'
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._loaded_options = None
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_id']._loaded_options = None
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_id']._serialized_options = b'\350\3071\001\212\3101\0041-50'
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER'].fields_by_name['database']._loaded_options = None
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER'].fields_by_name['database']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_properties']._loaded_options = None
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_properties']._serialized_options = b'\362\3071\024[-_0-9a-zA-Z.,:\\/_]*\202\3101\005<=256\212\3101\005<=128\262\3101\023\022\n[a-zA-Z_]*\032\0051-128'
  _globals['_CLICKHOUSECONNECTION'].oneofs_by_name['type']._loaded_options = None
  _globals['_CLICKHOUSECONNECTION'].oneofs_by_name['type']._serialized_options = b'\300\3011\001'
  _globals['_CLICKHOUSECONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_CLICKHOUSECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_CLICKHOUSECONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_CLICKHOUSECONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_TPCHCONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_TPCHCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_TPCHCONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_TPCHCONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_TPCDSCONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_TPCDSCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_TPCDSCONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_TPCDSCONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_ORACLECONNECTION_ONPREMISE'].fields_by_name['connection_url']._loaded_options = None
  _globals['_ORACLECONNECTION_ONPREMISE'].fields_by_name['connection_url']._serialized_options = b'\350\3071\001\362\3071\030^jdbc:[a-z0-9]+:(?s:.*)$'
  _globals['_ORACLECONNECTION_ONPREMISE'].fields_by_name['user_name']._loaded_options = None
  _globals['_ORACLECONNECTION_ONPREMISE'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_ORACLECONNECTION_ONPREMISE'].fields_by_name['password']._loaded_options = None
  _globals['_ORACLECONNECTION_ONPREMISE'].fields_by_name['password']._serialized_options = b'\350\3071\001\212\3101\0050-128'
  _globals['_ORACLECONNECTION'].oneofs_by_name['type']._loaded_options = None
  _globals['_ORACLECONNECTION'].oneofs_by_name['type']._serialized_options = b'\300\3011\001'
  _globals['_ORACLECONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_ORACLECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_ORACLECONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_ORACLECONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_SQLSERVERCONNECTION_ONPREMISE'].fields_by_name['connection_url']._loaded_options = None
  _globals['_SQLSERVERCONNECTION_ONPREMISE'].fields_by_name['connection_url']._serialized_options = b'\350\3071\001\362\3071\030^jdbc:[a-z0-9]+:(?s:.*)$'
  _globals['_SQLSERVERCONNECTION_ONPREMISE'].fields_by_name['user_name']._loaded_options = None
  _globals['_SQLSERVERCONNECTION_ONPREMISE'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_SQLSERVERCONNECTION_ONPREMISE'].fields_by_name['password']._loaded_options = None
  _globals['_SQLSERVERCONNECTION_ONPREMISE'].fields_by_name['password']._serialized_options = b'\350\3071\001\212\3101\0050-128'
  _globals['_SQLSERVERCONNECTION'].oneofs_by_name['type']._loaded_options = None
  _globals['_SQLSERVERCONNECTION'].oneofs_by_name['type']._serialized_options = b'\300\3011\001'
  _globals['_SQLSERVERCONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_SQLSERVERCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_SQLSERVERCONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_SQLSERVERCONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_CONNECTOR']._serialized_start=94
  _globals['_CONNECTOR']._serialized_end=662
  _globals['_CATALOG']._serialized_start=665
  _globals['_CATALOG']._serialized_end=881
  _globals['_CATALOG_LABELSENTRY']._serialized_start=836
  _globals['_CATALOG_LABELSENTRY']._serialized_end=881
  _globals['_CATALOGSPEC']._serialized_start=884
  _globals['_CATALOGSPEC']._serialized_end=1206
  _globals['_CATALOGSPEC_LABELSENTRY']._serialized_start=836
  _globals['_CATALOGSPEC_LABELSENTRY']._serialized_end=881
  _globals['_CATALOGUPDATESPEC']._serialized_start=1209
  _globals['_CATALOGUPDATESPEC']._serialized_end=1534
  _globals['_CATALOGUPDATESPEC_LABELSENTRY']._serialized_start=836
  _globals['_CATALOGUPDATESPEC_LABELSENTRY']._serialized_end=881
  _globals['_METASTORE']._serialized_start=1537
  _globals['_METASTORE']._serialized_end=1678
  _globals['_METASTORE_HIVEMETASTORE']._serialized_start=1614
  _globals['_METASTORE_HIVEMETASTORE']._serialized_end=1664
  _globals['_FILESYSTEM']._serialized_start=1681
  _globals['_FILESYSTEM']._serialized_end=2003
  _globals['_FILESYSTEM_S3FILESYSTEM']._serialized_start=1836
  _globals['_FILESYSTEM_S3FILESYSTEM']._serialized_end=1850
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM']._serialized_start=1853
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM']._serialized_end=1989
  _globals['_HIVECONNECTOR']._serialized_start=2006
  _globals['_HIVECONNECTOR']._serialized_end=2373
  _globals['_HIVECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2314
  _globals['_HIVECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2373
  _globals['_ICEBERGCONNECTOR']._serialized_start=2376
  _globals['_ICEBERGCONNECTOR']._serialized_end=2749
  _globals['_ICEBERGCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2314
  _globals['_ICEBERGCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2373
  _globals['_DELTALAKECONNECTOR']._serialized_start=2752
  _globals['_DELTALAKECONNECTOR']._serialized_end=3129
  _globals['_DELTALAKECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2314
  _globals['_DELTALAKECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2373
  _globals['_POSTGRESQLCONNECTION']._serialized_start=3132
  _globals['_POSTGRESQLCONNECTION']._serialized_end=3863
  _globals['_POSTGRESQLCONNECTION_ONPREMISE']._serialized_start=3327
  _globals['_POSTGRESQLCONNECTION_ONPREMISE']._serialized_end=3492
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER']._serialized_start=3495
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER']._serialized_end=3849
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._serialized_start=3790
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._serialized_end=3849
  _globals['_POSTGRESQLCONNECTOR']._serialized_start=3866
  _globals['_POSTGRESQLCONNECTOR']._serialized_end=4190
  _globals['_POSTGRESQLCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2314
  _globals['_POSTGRESQLCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2373
  _globals['_CLICKHOUSECONNECTION']._serialized_start=4193
  _globals['_CLICKHOUSECONNECTION']._serialized_end=4925
  _globals['_CLICKHOUSECONNECTION_ONPREMISE']._serialized_start=3327
  _globals['_CLICKHOUSECONNECTION_ONPREMISE']._serialized_end=3492
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER']._serialized_start=4556
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER']._serialized_end=4911
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._serialized_start=3790
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._serialized_end=3849
  _globals['_CLICKHOUSECONNECTOR']._serialized_start=4928
  _globals['_CLICKHOUSECONNECTOR']._serialized_end=5252
  _globals['_CLICKHOUSECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2314
  _globals['_CLICKHOUSECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2373
  _globals['_TPCHCONNECTOR']._serialized_start=5255
  _globals['_TPCHCONNECTOR']._serialized_end=5502
  _globals['_TPCHCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2314
  _globals['_TPCHCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2373
  _globals['_TPCDSCONNECTOR']._serialized_start=5505
  _globals['_TPCDSCONNECTOR']._serialized_end=5754
  _globals['_TPCDSCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2314
  _globals['_TPCDSCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2373
  _globals['_ORACLECONNECTION']._serialized_start=5757
  _globals['_ORACLECONNECTION']._serialized_end=6018
  _globals['_ORACLECONNECTION_ONPREMISE']._serialized_start=5851
  _globals['_ORACLECONNECTION_ONPREMISE']._serialized_end=6004
  _globals['_ORACLECONNECTOR']._serialized_start=6021
  _globals['_ORACLECONNECTOR']._serialized_end=6333
  _globals['_ORACLECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2314
  _globals['_ORACLECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2373
  _globals['_SQLSERVERCONNECTION']._serialized_start=6336
  _globals['_SQLSERVERCONNECTION']._serialized_end=6603
  _globals['_SQLSERVERCONNECTION_ONPREMISE']._serialized_start=5851
  _globals['_SQLSERVERCONNECTION_ONPREMISE']._serialized_end=6004
  _globals['_SQLSERVERCONNECTOR']._serialized_start=6606
  _globals['_SQLSERVERCONNECTOR']._serialized_end=6927
  _globals['_SQLSERVERCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2314
  _globals['_SQLSERVERCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2373
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cdn/v1/shielding_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cdn/v1/shielding_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.cdn.v1 import shielding_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_shielding__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/cdn/v1/shielding_service.proto\x12\x13yandex.cloud.cdn.v1\x1a yandex/cloud/api/operation.proto\x1a#yandex/cloud/cdn/v1/shielding.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"?\n\x1aGetShieldingDetailsRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"Z\n\x18\x41\x63tivateShieldingRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1b\n\x0blocation_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\">\n\x19\x41\x63tivateShieldingMetadata\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"?\n\x1a\x44\x65\x61\x63tivateShieldingRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"@\n\x1b\x44\x65\x61\x63tivateShieldingMetadata\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"X\n\x16UpdateShieldingRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1b\n\x0blocation_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"<\n\x17UpdateShieldingMetadata\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"~\n\x1dListShieldingLocationsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"}\n\x1eListShieldingLocationsResponse\x12\x42\n\x13shielding_locations\x18\x01 \x03(\x0b\x32%.yandex.cloud.cdn.v1.ShieldingDetails\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xb0\x05\n\x10ShieldingService\x12\x8f\x01\n\x08\x41\x63tivate\x12-.yandex.cloud.cdn.v1.ActivateShieldingRequest\x1a!.yandex.cloud.operation.Operation\"1\xb2\xd2*-\n\x19\x41\x63tivateShieldingMetadata\x12\x10ShieldingDetails\x12\x9a\x01\n\nDeactivate\x12/.yandex.cloud.cdn.v1.DeactivateShieldingRequest\x1a!.yandex.cloud.operation.Operation\"8\xb2\xd2*4\n\x1b\x44\x65\x61\x63tivateShieldingMetadata\x12\x15google.protobuf.Empty\x12]\n\x03Get\x12/.yandex.cloud.cdn.v1.GetShieldingDetailsRequest\x1a%.yandex.cloud.cdn.v1.ShieldingDetails\x12\x89\x01\n\x06Update\x12+.yandex.cloud.cdn.v1.UpdateShieldingRequest\x1a!.yandex.cloud.operation.Operation\"/\xb2\xd2*+\n\x17UpdateShieldingMetadata\x12\x10ShieldingDetails\x12\x81\x01\n\x16ListAvailableLocations\x12\x32.yandex.cloud.cdn.v1.ListShieldingLocationsRequest\x1a\x33.yandex.cloud.cdn.v1.ListShieldingLocationsResponseBV\n\x17yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdnb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cdn.v1.shielding_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdn'
  _globals['_GETSHIELDINGDETAILSREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_GETSHIELDINGDETAILSREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ACTIVATESHIELDINGREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_ACTIVATESHIELDINGREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ACTIVATESHIELDINGREQUEST'].fields_by_name['location_id']._loaded_options = None
  _globals['_ACTIVATESHIELDINGREQUEST'].fields_by_name['location_id']._serialized_options = b'\372\3071\002>0'
  _globals['_ACTIVATESHIELDINGMETADATA'].fields_by_name['resource_id']._loaded_options = None
  _globals['_ACTIVATESHIELDINGMETADATA'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DEACTIVATESHIELDINGREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_DEACTIVATESHIELDINGREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DEACTIVATESHIELDINGMETADATA'].fields_by_name['resource_id']._loaded_options = None
  _globals['_DEACTIVATESHIELDINGMETADATA'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATESHIELDINGREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_UPDATESHIELDINGREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATESHIELDINGREQUEST'].fields_by_name['location_id']._loaded_options = None
  _globals['_UPDATESHIELDINGREQUEST'].fields_by_name['location_id']._serialized_options = b'\372\3071\002>0'
  _globals['_UPDATESHIELDINGMETADATA'].fields_by_name['resource_id']._loaded_options = None
  _globals['_UPDATESHIELDINGMETADATA'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTSHIELDINGLOCATIONSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTSHIELDINGLOCATIONSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTSHIELDINGLOCATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSHIELDINGLOCATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTSHIELDINGLOCATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSHIELDINGLOCATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_SHIELDINGSERVICE'].methods_by_name['Activate']._loaded_options = None
  _globals['_SHIELDINGSERVICE'].methods_by_name['Activate']._serialized_options = b'\262\322*-\n\031ActivateShieldingMetadata\022\020ShieldingDetails'
  _globals['_SHIELDINGSERVICE'].methods_by_name['Deactivate']._loaded_options = None
  _globals['_SHIELDINGSERVICE'].methods_by_name['Deactivate']._serialized_options = b'\262\322*4\n\033DeactivateShieldingMetadata\022\025google.protobuf.Empty'
  _globals['_SHIELDINGSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_SHIELDINGSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*+\n\027UpdateShieldingMetadata\022\020ShieldingDetails'
  _globals['_GETSHIELDINGDETAILSREQUEST']._serialized_start=210
  _globals['_GETSHIELDINGDETAILSREQUEST']._serialized_end=273
  _globals['_ACTIVATESHIELDINGREQUEST']._serialized_start=275
  _globals['_ACTIVATESHIELDINGREQUEST']._serialized_end=365
  _globals['_ACTIVATESHIELDINGMETADATA']._serialized_start=367
  _globals['_ACTIVATESHIELDINGMETADATA']._serialized_end=429
  _globals['_DEACTIVATESHIELDINGREQUEST']._serialized_start=431
  _globals['_DEACTIVATESHIELDINGREQUEST']._serialized_end=494
  _globals['_DEACTIVATESHIELDINGMETADATA']._serialized_start=496
  _globals['_DEACTIVATESHIELDINGMETADATA']._serialized_end=560
  _globals['_UPDATESHIELDINGREQUEST']._serialized_start=562
  _globals['_UPDATESHIELDINGREQUEST']._serialized_end=650
  _globals['_UPDATESHIELDINGMETADATA']._serialized_start=652
  _globals['_UPDATESHIELDINGMETADATA']._serialized_end=712
  _globals['_LISTSHIELDINGLOCATIONSREQUEST']._serialized_start=714
  _globals['_LISTSHIELDINGLOCATIONSREQUEST']._serialized_end=840
  _globals['_LISTSHIELDINGLOCATIONSRESPONSE']._serialized_start=842
  _globals['_LISTSHIELDINGLOCATIONSRESPONSE']._serialized_end=967
  _globals['_SHIELDINGSERVICE']._serialized_start=970
  _globals['_SHIELDINGSERVICE']._serialized_end=1658
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/marketplace/v1/metering/usage_record.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/marketplace/v1/metering/usage_record.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7yandex/cloud/marketplace/v1/metering/usage_record.proto\x12$yandex.cloud.marketplace.v1.metering\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\x96\x01\n\x0bUsageRecord\x12\x1a\n\x04uuid\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=36\x12\x1c\n\x06sku_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x18\n\x08quantity\x18\x03 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\x12\x33\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\"#\n\x13\x41\x63\x63\x65ptedUsageRecord\x12\x0c\n\x04uuid\x18\x01 \x01(\t\"\x9d\x02\n\x13RejectedUsageRecord\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12P\n\x06reason\x18\x02 \x01(\x0e\x32@.yandex.cloud.marketplace.v1.metering.RejectedUsageRecord.Reason\"\xa5\x01\n\x06Reason\x12\x16\n\x12REASON_UNSPECIFIED\x10\x00\x12\r\n\tDUPLICATE\x10\x01\x12\x0b\n\x07\x45XPIRED\x10\x02\x12\x15\n\x11INVALID_TIMESTAMP\x10\x03\x12\x12\n\x0eINVALID_SKU_ID\x10\x04\x12\x16\n\x12INVALID_PRODUCT_ID\x10\x05\x12\x14\n\x10INVALID_QUANTITY\x10\x06\x12\x0e\n\nINVALID_ID\x10\x07\x42}\n(yandex.cloud.api.marketplace.v1.meteringZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/v1/metering;meteringb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.marketplace.v1.metering.usage_record_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.marketplace.v1.meteringZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/v1/metering;metering'
  _globals['_USAGERECORD'].fields_by_name['uuid']._loaded_options = None
  _globals['_USAGERECORD'].fields_by_name['uuid']._serialized_options = b'\350\3071\001\212\3101\004<=36'
  _globals['_USAGERECORD'].fields_by_name['sku_id']._loaded_options = None
  _globals['_USAGERECORD'].fields_by_name['sku_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_USAGERECORD'].fields_by_name['quantity']._loaded_options = None
  _globals['_USAGERECORD'].fields_by_name['quantity']._serialized_options = b'\372\3071\002>0'
  _globals['_USAGERECORD'].fields_by_name['timestamp']._loaded_options = None
  _globals['_USAGERECORD'].fields_by_name['timestamp']._serialized_options = b'\350\3071\001'
  _globals['_USAGERECORD']._serialized_start=162
  _globals['_USAGERECORD']._serialized_end=312
  _globals['_ACCEPTEDUSAGERECORD']._serialized_start=314
  _globals['_ACCEPTEDUSAGERECORD']._serialized_end=349
  _globals['_REJECTEDUSAGERECORD']._serialized_start=352
  _globals['_REJECTEDUSAGERECORD']._serialized_end=637
  _globals['_REJECTEDUSAGERECORD_REASON']._serialized_start=472
  _globals['_REJECTEDUSAGERECORD_REASON']._serialized_end=637
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.ai.tuning.v1 import tuning_service_pb2 as yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/ai/tuning/v1/tuning_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class TuningServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Tune = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/Tune',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.TuningRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/List',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListTuningsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListTuningsResponse.FromString,
                _registered_method=True)
        self.Describe = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/Describe',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DescribeTuningRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DescribeTuningResponse.FromString,
                _registered_method=True)
        self.Cancel = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/Cancel',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CancelTuningRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CancelTuningResponse.FromString,
                _registered_method=True)
        self.GetMetricsUrl = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/GetMetricsUrl',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetMetricsUrlRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetMetricsUrlResponse.FromString,
                _registered_method=True)
        self.GetOptions = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/GetOptions',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetOptionsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetOptionsResponse.FromString,
                _registered_method=True)
        self.ListErrors = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/ListErrors',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListErrorsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListErrorsResponse.FromString,
                _registered_method=True)
        self.CreateDraft = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/CreateDraft',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CreateTuningDraftRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CreateTuningDraftResponse.FromString,
                _registered_method=True)
        self.UpdateDraft = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/UpdateDraft',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.UpdateTuningDraftRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.UpdateTuningDraftResponse.FromString,
                _registered_method=True)
        self.DeleteDraft = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/DeleteDraft',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DeleteTuningDraftRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DeleteTuningDraftResponse.FromString,
                _registered_method=True)
        self.TuneDraft = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/TuneDraft',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.TuneDraftRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Archive = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/Archive',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ArchiveTuningRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.EnableBilling = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/EnableBilling',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.EnableBillingRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)


class TuningServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Tune(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Describe(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Cancel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMetricsUrl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOptions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListErrors(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDraft(self, request, context):
        """Unimplemented
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDraft(self, request, context):
        """Unimplemented
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDraft(self, request, context):
        """Unimplemented
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TuneDraft(self, request, context):
        """Unimplemented
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Archive(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableBilling(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TuningServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Tune': grpc.unary_unary_rpc_method_handler(
                    servicer.Tune,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.TuningRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListTuningsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListTuningsResponse.SerializeToString,
            ),
            'Describe': grpc.unary_unary_rpc_method_handler(
                    servicer.Describe,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DescribeTuningRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DescribeTuningResponse.SerializeToString,
            ),
            'Cancel': grpc.unary_unary_rpc_method_handler(
                    servicer.Cancel,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CancelTuningRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CancelTuningResponse.SerializeToString,
            ),
            'GetMetricsUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMetricsUrl,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetMetricsUrlRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetMetricsUrlResponse.SerializeToString,
            ),
            'GetOptions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOptions,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetOptionsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetOptionsResponse.SerializeToString,
            ),
            'ListErrors': grpc.unary_unary_rpc_method_handler(
                    servicer.ListErrors,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListErrorsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListErrorsResponse.SerializeToString,
            ),
            'CreateDraft': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDraft,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CreateTuningDraftRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CreateTuningDraftResponse.SerializeToString,
            ),
            'UpdateDraft': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDraft,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.UpdateTuningDraftRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.UpdateTuningDraftResponse.SerializeToString,
            ),
            'DeleteDraft': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDraft,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DeleteTuningDraftRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DeleteTuningDraftResponse.SerializeToString,
            ),
            'TuneDraft': grpc.unary_unary_rpc_method_handler(
                    servicer.TuneDraft,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.TuneDraftRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Archive': grpc.unary_unary_rpc_method_handler(
                    servicer.Archive,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ArchiveTuningRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'EnableBilling': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableBilling,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.EnableBillingRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.ai.tuning.v1.TuningService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.ai.tuning.v1.TuningService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class TuningService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Tune(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.tuning.v1.TuningService/Tune',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.TuningRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.tuning.v1.TuningService/List',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListTuningsRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListTuningsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Describe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.tuning.v1.TuningService/Describe',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DescribeTuningRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DescribeTuningResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Cancel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.tuning.v1.TuningService/Cancel',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CancelTuningRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CancelTuningResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetMetricsUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.tuning.v1.TuningService/GetMetricsUrl',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetMetricsUrlRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetMetricsUrlResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetOptions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.tuning.v1.TuningService/GetOptions',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetOptionsRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetOptionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListErrors(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.tuning.v1.TuningService/ListErrors',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListErrorsRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListErrorsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateDraft(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.tuning.v1.TuningService/CreateDraft',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CreateTuningDraftRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CreateTuningDraftResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateDraft(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.tuning.v1.TuningService/UpdateDraft',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.UpdateTuningDraftRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.UpdateTuningDraftResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteDraft(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.tuning.v1.TuningService/DeleteDraft',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DeleteTuningDraftRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DeleteTuningDraftResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TuneDraft(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.tuning.v1.TuningService/TuneDraft',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.TuneDraftRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Archive(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.tuning.v1.TuningService/Archive',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ArchiveTuningRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def EnableBilling(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.tuning.v1.TuningService/EnableBilling',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.EnableBillingRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/video/v1/thumbnail.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/video/v1/thumbnail.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%yandex/cloud/video/v1/thumbnail.proto\x12\x15yandex.cloud.video.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa1\x01\n\tThumbnail\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x15\n\nepisode_id\x18\xeb\x07 \x01(\tH\x00\x12\x13\n\x08video_id\x18\xec\x07 \x01(\tH\x00\x12.\n\ncreated_at\x18\x64 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x0b\n\tparent_idJ\x04\x08\x03\x10\x64J\x05\x08\x65\x10\xeb\x07\x42\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.thumbnail_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _globals['_THUMBNAIL']._serialized_start=98
  _globals['_THUMBNAIL']._serialized_end=259
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/iam/v1/key.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/iam/v1/key.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dyandex/cloud/iam/v1/key.proto\x12\x13yandex.cloud.iam.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe5\x02\n\x03Key\x12\n\n\x02id\x18\x01 \x01(\t\x12\x19\n\x0fuser_account_id\x18\x02 \x01(\tH\x00\x12\x1c\n\x12service_account_id\x18\x03 \x01(\tH\x00\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x39\n\rkey_algorithm\x18\x06 \x01(\x0e\x32\".yandex.cloud.iam.v1.Key.Algorithm\x12\x12\n\npublic_key\x18\x07 \x01(\t\x12\x30\n\x0clast_used_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"B\n\tAlgorithm\x12\x19\n\x15\x41LGORITHM_UNSPECIFIED\x10\x00\x12\x0c\n\x08RSA_2048\x10\x01\x12\x0c\n\x08RSA_4096\x10\x02\x42\t\n\x07subjectJ\x04\x08\x08\x10\tBV\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.key_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'
  _globals['_KEY']._serialized_start=88
  _globals['_KEY']._serialized_end=445
  _globals['_KEY_ALGORITHM']._serialized_start=362
  _globals['_KEY_ALGORITHM']._serialized_end=428
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class LifecyclePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[LifecyclePolicy._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: LifecyclePolicy._Status.ValueType  # 0
        ACTIVE: LifecyclePolicy._Status.ValueType  # 1
        """Policy is active and regularly deletes Docker images according to the established rules."""
        DISABLED: LifecyclePolicy._Status.ValueType  # 2
        """Policy is disabled and does not delete Docker images in the repository.
        Policies in this status can be used for preparing and testing rules.
        """

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: LifecyclePolicy.Status.ValueType  # 0
    ACTIVE: LifecyclePolicy.Status.ValueType  # 1
    """Policy is active and regularly deletes Docker images according to the established rules."""
    DISABLED: LifecyclePolicy.Status.ValueType  # 2
    """Policy is disabled and does not delete Docker images in the repository.
    Policies in this status can be used for preparing and testing rules.
    """

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    REPOSITORY_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the lifecycle policy."""
    name: builtins.str
    """Name of the lifecycle policy."""
    repository_id: builtins.str
    """ID of the repository that the lifecycle policy belongs to.
    Required. The maximum string length in characters is 50.
    """
    description: builtins.str
    """Description of the lifecycle policy.
    The maximum string length in characters is 256.
    """
    status: global___LifecyclePolicy.Status.ValueType
    """Status of lifecycle policy."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LifecycleRule]:
        """The rules of lifecycle policy."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        repository_id: builtins.str = ...,
        description: builtins.str = ...,
        status: global___LifecyclePolicy.Status.ValueType = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        rules: collections.abc.Iterable[global___LifecycleRule] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "id", b"id", "name", b"name", "repository_id", b"repository_id", "rules", b"rules", "status", b"status"]) -> None: ...

global___LifecyclePolicy = LifecyclePolicy

@typing.final
class LifecycleRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPIRE_PERIOD_FIELD_NUMBER: builtins.int
    TAG_REGEXP_FIELD_NUMBER: builtins.int
    UNTAGGED_FIELD_NUMBER: builtins.int
    RETAINED_TOP_FIELD_NUMBER: builtins.int
    description: builtins.str
    """Description of the lifecycle policy rule."""
    tag_regexp: builtins.str
    """Tag for specifying a filter in the form of a regular expression."""
    untagged: builtins.bool
    """Tag for applying the rule to Docker images without tags."""
    retained_top: builtins.int
    """Number of Docker images (falling under the specified filter by tags) that must be left, even if the expire_period has already expired."""
    @property
    def expire_period(self) -> google.protobuf.duration_pb2.Duration:
        """Period of time for automatic deletion.
        Period must be a multiple of 24 hours.
        """

    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expire_period: google.protobuf.duration_pb2.Duration | None = ...,
        tag_regexp: builtins.str = ...,
        untagged: builtins.bool = ...,
        retained_top: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["expire_period", b"expire_period"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "expire_period", b"expire_period", "retained_top", b"retained_top", "tag_regexp", b"tag_regexp", "untagged", b"untagged"]) -> None: ...

global___LifecycleRule = LifecycleRule



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/metastore/v1/cluster_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/metastore/v1/cluster_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.metastore.v1 import cluster_pb2 as yandex_dot_cloud_dot_metastore_dot_v1_dot_cluster__pb2
from yandex.cloud.metastore.v1 import maintenance_pb2 as yandex_dot_cloud_dot_metastore_dot_v1_dot_maintenance__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/metastore/v1/cluster_service.proto\x12\x19yandex.cloud.metastore.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\'yandex/cloud/metastore/v1/cluster.proto\x1a+yandex/cloud/metastore/v1/maintenance.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"5\n\x11GetClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x13ListClustersRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"e\n\x14ListClustersResponse\x12\x34\n\x08\x63lusters\x18\x01 \x03(\x0b\x32\".yandex.cloud.metastore.v1.Cluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x99\x05\n\x14\x43reateClusterRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x88\x01\n\x06labels\x18\x04 \x03(\x0b\x32;.yandex.cloud.metastore.v1.CreateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x1b\n\x13\x64\x65letion_protection\x18\x0b \x01(\x08\x12\x0f\n\x07version\x18\x0c \x01(\t\x12:\n\x0b\x63onfig_spec\x18\r \x01(\x0b\x32%.yandex.cloud.metastore.v1.ConfigSpec\x12(\n\x12service_account_id\x18\x0e \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x39\n\x07logging\x18\x0f \x01(\x0b\x32(.yandex.cloud.metastore.v1.LoggingConfig\x12\x39\n\x07network\x18\x10 \x01(\x0b\x32(.yandex.cloud.metastore.v1.NetworkConfig\x12H\n\x12maintenance_window\x18\x11 \x01(\x0b\x32,.yandex.cloud.metastore.v1.MaintenanceWindow\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x05\x10\x0b\"+\n\x15\x43reateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xd7\x05\n\x14UpdateClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12 \n\x04name\x18\x03 \x01(\tB\x12\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x88\x01\n\x06labels\x18\x05 \x03(\x0b\x32;.yandex.cloud.metastore.v1.UpdateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x1b\n\x13\x64\x65letion_protection\x18\x07 \x01(\x08\x12$\n\x12service_account_id\x18\x08 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x39\n\x07logging\x18\t \x01(\x0b\x32(.yandex.cloud.metastore.v1.LoggingConfig\x12H\n\x0cnetwork_spec\x18\n \x01(\x0b\x32\x32.yandex.cloud.metastore.v1.UpdateNetworkConfigSpec\x12G\n\x0b\x63onfig_spec\x18\x0b \x01(\x0b\x32\x32.yandex.cloud.metastore.v1.UpdateClusterConfigSpec\x12H\n\x12maintenance_window\x18\x0c \x01(\x0b\x32,.yandex.cloud.metastore.v1.MaintenanceWindow\x12\x0f\n\x07version\x18\r \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x06\x10\x07\"+\n\x15UpdateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"7\n\x13StartClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"*\n\x14StartClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"6\n\x12StopClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13StopClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"c\n\x11ImportDataRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x14\n\x06\x62ucket\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x16\n\x08\x66ilepath\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\"(\n\x12ImportDataMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"c\n\x11\x45xportDataRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x14\n\x06\x62ucket\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x16\n\x08\x66ilepath\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\"(\n\x12\x45xportDataMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"~\n\x1cListClusterOperationsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"o\n\x1dListClusterOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"K\n\nConfigSpec\x12\x37\n\tresources\x18\x02 \x01(\x0b\x32$.yandex.cloud.metastore.v1.ResourcesJ\x04\x08\x01\x10\x02\"R\n\x17UpdateClusterConfigSpec\x12\x37\n\tresources\x18\x01 \x01(\x0b\x32$.yandex.cloud.metastore.v1.Resources\"5\n\x17UpdateNetworkConfigSpec\x12\x1a\n\x12security_group_ids\x18\x01 \x03(\t2\x98\x0e\n\x0e\x43lusterService\x12\x8c\x01\n\x03Get\x12,.yandex.cloud.metastore.v1.GetClusterRequest\x1a\".yandex.cloud.metastore.v1.Cluster\"3\x82\xd3\xe4\x93\x02-\x12+/managed-metastore/v1/clusters/{cluster_id}\x12\x8f\x01\n\x04List\x12..yandex.cloud.metastore.v1.ListClustersRequest\x1a/.yandex.cloud.metastore.v1.ListClustersResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/managed-metastore/v1/clusters\x12\xab\x01\n\x06\x43reate\x12/.yandex.cloud.metastore.v1.CreateClusterRequest\x1a!.yandex.cloud.operation.Operation\"M\xb2\xd2* \n\x15\x43reateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02#\"\x1e/managed-metastore/v1/clusters:\x01*\x12\xb8\x01\n\x06Update\x12/.yandex.cloud.metastore.v1.UpdateClusterRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2* \n\x15UpdateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x30\x32+/managed-metastore/v1/clusters/{cluster_id}:\x01*\x12\xc3\x01\n\x06\x44\x65lete\x12/.yandex.cloud.metastore.v1.DeleteClusterRequest\x1a!.yandex.cloud.operation.Operation\"e\xb2\xd2*.\n\x15\x44\x65leteClusterMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02-*+/managed-metastore/v1/clusters/{cluster_id}\x12\xb8\x01\n\x05Start\x12..yandex.cloud.metastore.v1.StartClusterRequest\x1a!.yandex.cloud.operation.Operation\"\\\xb2\xd2*\x1f\n\x14StartClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x33\"1/managed-metastore/v1/clusters/{cluster_id}:start\x12\xb4\x01\n\x04Stop\x12-.yandex.cloud.metastore.v1.StopClusterRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2*\x1e\n\x13StopClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x32\"0/managed-metastore/v1/clusters/{cluster_id}:stop\x12\xbd\x01\n\nImportData\x12,.yandex.cloud.metastore.v1.ImportDataRequest\x1a!.yandex.cloud.operation.Operation\"^\xb2\xd2*\x1d\n\x12ImportDataMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x37\"2/managed-metastore/v1/clusters/{cluster_id}:import:\x01*\x12\xbd\x01\n\nExportData\x12,.yandex.cloud.metastore.v1.ExportDataRequest\x1a!.yandex.cloud.operation.Operation\"^\xb2\xd2*\x1d\n\x12\x45xportDataMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x37\"2/managed-metastore/v1/clusters/{cluster_id}:export:\x01*\x12\xc3\x01\n\x0eListOperations\x12\x37.yandex.cloud.metastore.v1.ListClusterOperationsRequest\x1a\x38.yandex.cloud.metastore.v1.ListClusterOperationsResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/managed-metastore/v1/clusters/{cluster_id}/operationsBh\n\x1dyandex.cloud.api.metastore.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/metastore/v1;metastoreb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.metastore.v1.cluster_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035yandex.cloud.api.metastore.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/metastore/v1;metastore'
  _globals['_GETCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['service_account_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['service_account_id']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['service_account_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STARTCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STARTCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STOPCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STOPCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_IMPORTDATAREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_IMPORTDATAREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_IMPORTDATAREQUEST'].fields_by_name['bucket']._loaded_options = None
  _globals['_IMPORTDATAREQUEST'].fields_by_name['bucket']._serialized_options = b'\350\3071\001'
  _globals['_IMPORTDATAREQUEST'].fields_by_name['filepath']._loaded_options = None
  _globals['_IMPORTDATAREQUEST'].fields_by_name['filepath']._serialized_options = b'\350\3071\001'
  _globals['_EXPORTDATAREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_EXPORTDATAREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_EXPORTDATAREQUEST'].fields_by_name['bucket']._loaded_options = None
  _globals['_EXPORTDATAREQUEST'].fields_by_name['bucket']._serialized_options = b'\350\3071\001'
  _globals['_EXPORTDATAREQUEST'].fields_by_name['filepath']._loaded_options = None
  _globals['_EXPORTDATAREQUEST'].fields_by_name['filepath']._serialized_options = b'\350\3071\001'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_CLUSTERSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002-\022+/managed-metastore/v1/clusters/{cluster_id}'
  _globals['_CLUSTERSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002 \022\036/managed-metastore/v1/clusters'
  _globals['_CLUSTERSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateClusterMetadata\022\007Cluster\202\323\344\223\002#\"\036/managed-metastore/v1/clusters:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateClusterMetadata\022\007Cluster\202\323\344\223\00202+/managed-metastore/v1/clusters/{cluster_id}:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteClusterMetadata\022\025google.protobuf.Empty\202\323\344\223\002-*+/managed-metastore/v1/clusters/{cluster_id}'
  _globals['_CLUSTERSERVICE'].methods_by_name['Start']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Start']._serialized_options = b'\262\322*\037\n\024StartClusterMetadata\022\007Cluster\202\323\344\223\0023\"1/managed-metastore/v1/clusters/{cluster_id}:start'
  _globals['_CLUSTERSERVICE'].methods_by_name['Stop']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Stop']._serialized_options = b'\262\322*\036\n\023StopClusterMetadata\022\007Cluster\202\323\344\223\0022\"0/managed-metastore/v1/clusters/{cluster_id}:stop'
  _globals['_CLUSTERSERVICE'].methods_by_name['ImportData']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ImportData']._serialized_options = b'\262\322*\035\n\022ImportDataMetadata\022\007Cluster\202\323\344\223\0027\"2/managed-metastore/v1/clusters/{cluster_id}:import:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['ExportData']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ExportData']._serialized_options = b'\262\322*\035\n\022ExportDataMetadata\022\007Cluster\202\323\344\223\0027\"2/managed-metastore/v1/clusters/{cluster_id}:export:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0028\0226/managed-metastore/v1/clusters/{cluster_id}/operations'
  _globals['_GETCLUSTERREQUEST']._serialized_start=333
  _globals['_GETCLUSTERREQUEST']._serialized_end=386
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=389
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=533
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=535
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=636
  _globals['_CREATECLUSTERREQUEST']._serialized_start=639
  _globals['_CREATECLUSTERREQUEST']._serialized_end=1304
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1253
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1298
  _globals['_CREATECLUSTERMETADATA']._serialized_start=1306
  _globals['_CREATECLUSTERMETADATA']._serialized_end=1349
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=1352
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=2079
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1253
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1298
  _globals['_UPDATECLUSTERMETADATA']._serialized_start=2081
  _globals['_UPDATECLUSTERMETADATA']._serialized_end=2124
  _globals['_DELETECLUSTERREQUEST']._serialized_start=2126
  _globals['_DELETECLUSTERREQUEST']._serialized_end=2182
  _globals['_DELETECLUSTERMETADATA']._serialized_start=2184
  _globals['_DELETECLUSTERMETADATA']._serialized_end=2227
  _globals['_STARTCLUSTERREQUEST']._serialized_start=2229
  _globals['_STARTCLUSTERREQUEST']._serialized_end=2284
  _globals['_STARTCLUSTERMETADATA']._serialized_start=2286
  _globals['_STARTCLUSTERMETADATA']._serialized_end=2328
  _globals['_STOPCLUSTERREQUEST']._serialized_start=2330
  _globals['_STOPCLUSTERREQUEST']._serialized_end=2384
  _globals['_STOPCLUSTERMETADATA']._serialized_start=2386
  _globals['_STOPCLUSTERMETADATA']._serialized_end=2427
  _globals['_IMPORTDATAREQUEST']._serialized_start=2429
  _globals['_IMPORTDATAREQUEST']._serialized_end=2528
  _globals['_IMPORTDATAMETADATA']._serialized_start=2530
  _globals['_IMPORTDATAMETADATA']._serialized_end=2570
  _globals['_EXPORTDATAREQUEST']._serialized_start=2572
  _globals['_EXPORTDATAREQUEST']._serialized_end=2671
  _globals['_EXPORTDATAMETADATA']._serialized_start=2673
  _globals['_EXPORTDATAMETADATA']._serialized_end=2713
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_start=2715
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_end=2841
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_start=2843
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_end=2954
  _globals['_CONFIGSPEC']._serialized_start=2956
  _globals['_CONFIGSPEC']._serialized_end=3031
  _globals['_UPDATECLUSTERCONFIGSPEC']._serialized_start=3033
  _globals['_UPDATECLUSTERCONFIGSPEC']._serialized_end=3115
  _globals['_UPDATENETWORKCONFIGSPEC']._serialized_start=3117
  _globals['_UPDATENETWORKCONFIGSPEC']._serialized_end=3170
  _globals['_CLUSTERSERVICE']._serialized_start=3173
  _globals['_CLUSTERSERVICE']._serialized_end=4989
# @@protoc_insertion_point(module_scope)
